@@ -25,18 +25,13 @@
 #ifndef CHAT_MESSENGER_H_
 #define CHAT_MESSENGER_H_
 
-#include <gnunet/platform.h>
 #include <gnunet/gnunet_chat_lib.h>
-#include <gnunet/gnunet_common.h>
-#include <gnunet/gnunet_program_lib.h>
 
 typedef struct MESSENGER_Application MESSENGER_Application;
 
 typedef struct CHAT_MESSENGER_Handle
 {
   struct GNUNET_CHAT_Handle *handle;
-  struct GNUNET_SCHEDULER_Task *quit;
-  struct GNUNET_SCHEDULER_Task *idle;
 } CHAT_MESSENGER_Handle;
 
 /**
