@@ -31,7 +31,7 @@
 
 typedef struct UI_CONTACT_ENTRY_Handle
 {
-  const struct GNUNET_CHAT_Contact *contact;
+  struct GNUNET_CHAT_Contact *contact;
 
   GtkBuilder *builder;
 
@@ -63,7 +63,7 @@ ui_contact_entry_new(MESSENGER_Application *app);
  */
 void
 ui_contact_entry_set_contact(UI_CONTACT_ENTRY_Handle* handle,
-                             const struct GNUNET_CHAT_Contact *contact);
+                             struct GNUNET_CHAT_Contact *contact);
 
 /**
  * Frees its resources and destroys a given
