@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2022--2024 GNUnet e.V.
+   Copyright (C) 2022--2025 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -33,6 +33,7 @@
 #include "../ui.h"
 
 #include <gnunet/gnunet_chat_lib.h>
+#include <gnunet/gnunet_common.h>
 #include <string.h>
 
 static void
@@ -303,6 +304,38 @@ handle_unblock_button_click(UNUSED GtkButton *button,
   );
 }
 
+static void*
+_open_direct_chat(MESSENGER_Application *app,
+                  struct GNUNET_CHAT_Contact *contact)
+{
+  g_assert((app) && (contact));
+
+  application_chat_lock(app);
+
+  struct GNUNET_CHAT_Context *context = GNUNET_CHAT_contact_get_context(
+    contact
+  );
+
+  if (!context)
+    return GNUNET_NO;
+
+  void *user_pointer = NULL;;
+  enum GNUNET_GenericReturnValue status = GNUNET_CHAT_context_get_status(
+    context
+  );
+
+  if (GNUNET_SYSERR != status)
+    user_pointer = GNUNET_CHAT_context_get_user_pointer(
+      context
+    );
+  else
+    GNUNET_CHAT_context_request(context);
+
+  application_chat_unlock(app);
+
+  return user_pointer;
+}
+
 static void
 handle_open_chat_button_click(UNUSED GtkButton *button,
                               gpointer user_data)
@@ -314,30 +347,19 @@ handle_open_chat_button_click(UNUSED GtkButton *button,
   if (!(handle->contact))
     return;
 
-  struct GNUNET_CHAT_Context *context = GNUNET_CHAT_contact_get_context(
-    handle->contact
+  UI_CHAT_ENTRY_Handle *entry = _open_direct_chat(
+    handle->app, handle->contact
   );
 
-  if (!context)
-    return;
-
-  if (GNUNET_SYSERR == GNUNET_CHAT_context_get_status(context))
-  {
-    GNUNET_CHAT_context_request(context);
-    goto close_dialog;
-  }
-
-  UI_CHAT_ENTRY_Handle *entry = GNUNET_CHAT_context_get_user_pointer(context);
-
   if ((!entry) || (!(entry->entry_box)))
-    return;
+    goto close_dialog;
 
   GtkListBoxRow *row = GTK_LIST_BOX_ROW(
     gtk_widget_get_parent(entry->entry_box)
   );
 
   if (!row)
-    return;
+    goto close_dialog;
 
   gtk_list_box_select_row(handle->app->ui.messenger.chats_listbox, row);
   gtk_list_box_invalidate_filter(handle->app->ui.messenger.chats_listbox);
@@ -1328,6 +1350,10 @@ ui_contact_info_dialog_init(MESSENGER_Application *app,
     handle
   );
 
+  handle->open_chat_stack = GTK_STACK(
+    gtk_builder_get_object(handle->builder, "open_chat_stack")
+  );
+
   handle->back_button = GTK_BUTTON(
     gtk_builder_get_object(handle->builder, "back_button")
   );
@@ -1393,6 +1419,9 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
 {
   g_assert(handle);
 
+  if (!contact)
+    contact = GNUNET_CHAT_get_own_contact(handle->app->chat.messenger.handle);
+
   const char *name = NULL;
   const char *key = NULL;
 
@@ -1567,6 +1596,11 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
     );
   }
 
+  gtk_stack_set_visible_child_name(
+    handle->open_chat_stack,
+    editable? "open_notes_page" : "open_private_chat_page"
+  );
+
   struct GNUNET_CHAT_Context *context = GNUNET_CHAT_contact_get_context(
     contact
   );
@@ -1578,7 +1612,7 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
 
   gtk_widget_set_visible(
     GTK_WIDGET(handle->open_chat_button),
-    !editable
+    context? TRUE : FALSE
   );
 
   if (reveal)
