@@ -137,6 +137,42 @@ handle_file_button_click(GtkButton *button,
   }
 }
 
+static void
+handle_accept_button_click(GtkButton *button,
+                           gpointer user_data)
+{
+  g_assert((button) && (user_data));
+
+  MESSENGER_Application *app = (MESSENGER_Application*) user_data;
+
+  UI_MESSAGE_Handle* handle = (UI_MESSAGE_Handle*) (
+      g_object_get_qdata(G_OBJECT(button), app->quarks.ui)
+  );
+
+  if ((!handle) || (!(handle->status_cb)))
+    return;
+
+  handle->status_cb(app, true, handle->status_cls);
+}
+
+static void
+handle_deny_button_click(GtkButton *button,
+                         gpointer user_data)
+{
+  g_assert((button) && (user_data));
+
+  MESSENGER_Application *app = (MESSENGER_Application*) user_data;
+
+  UI_MESSAGE_Handle* handle = (UI_MESSAGE_Handle*) (
+      g_object_get_qdata(G_OBJECT(button), app->quarks.ui)
+  );
+
+  if ((!handle) || (!(handle->status_cb)))
+    return;
+
+  handle->status_cb(app, false, handle->status_cls);
+}
+
 static void
 handle_media_button_click(GtkButton *button,
                           gpointer user_data)
@@ -266,6 +302,9 @@ ui_message_new(MESSENGER_Application *app,
   handle->msg = NULL;
   handle->contact = NULL;
 
+  handle->status_cb = NULL;
+  handle->status_cls = NULL;
+
   const char *ui_builder_file;
 
   switch (handle->type)
@@ -318,6 +357,23 @@ ui_message_new(MESSENGER_Application *app,
     handle->accept_button = GTK_BUTTON(
 	    gtk_builder_get_object(handle->builder[0], "accept_button")
     );
+
+    g_object_set_qdata(G_OBJECT(handle->accept_button), app->quarks.ui, handle);
+    g_object_set_qdata(G_OBJECT(handle->deny_button), app->quarks.ui, handle);
+
+    g_signal_connect(
+      handle->accept_button,
+      "clicked",
+      G_CALLBACK(handle_accept_button_click),
+      app
+    );
+
+    g_signal_connect(
+      handle->deny_button,
+      "clicked",
+      G_CALLBACK(handle_deny_button_click),
+      app
+    );
   }
   else
   {
@@ -418,6 +474,8 @@ ui_message_new(MESSENGER_Application *app,
 
   handle->app = app;
 
+  g_object_set_qdata(G_OBJECT(handle->media_button), app->quarks.ui, handle);
+
   g_signal_connect(
     handle->media_button,
     "clicked",
@@ -425,8 +483,6 @@ ui_message_new(MESSENGER_Application *app,
     app
   );
 
-  g_object_set_qdata(G_OBJECT(handle->media_button), app->quarks.ui, handle);
-
   switch (handle->type)
   {
     case UI_MESSAGE_STATUS:
@@ -690,8 +746,14 @@ ui_message_update(UI_MESSAGE_Handle *handle,
   struct GNUNET_CHAT_File *file = NULL;
   struct GNUNET_CHAT_Invitation *invitation = NULL;
 
+  if (handle->msg)
+    GNUNET_CHAT_message_set_user_pointer(handle->msg, NULL);
+
   handle->msg = msg;
 
+  if (msg)
+    GNUNET_CHAT_message_set_user_pointer(msg, handle);
+
   ui_message_refresh(handle);
 
   if (msg)
@@ -751,6 +813,17 @@ ui_message_set_contact(UI_MESSAGE_Handle *handle,
   handle->contact = contact;
 }
 
+void
+ui_message_set_status_callback(UI_MESSAGE_Handle *handle,
+                               UI_MESSAGE_StatusCallback cb,
+                               gpointer cls)
+{
+  g_assert(handle);
+
+  handle->status_cb = cb;
+  handle->status_cls = cls;
+}
+
 void
 ui_message_add_tag(UI_MESSAGE_Handle *handle,
                    MESSENGER_Application *app,
