@@ -102,12 +102,16 @@ handle_send_button_click(GtkButton *button,
     gtk_label_set_text(file_load->file_label, filename);
     gtk_progress_bar_set_fraction(file_load->load_progress_bar, 0.0);
 
+    application_chat_lock(app);
+
     file = GNUNET_CHAT_context_send_file(
       context,
       filename,
       handle_sending_upload_file,
       file_load
     );
+
+    application_chat_unlock(app);
   }
 
   g_free(filename);
